#!/bin/sh

# Shell script for monthly backups
# By Chris Travers (chris@travelamericas.com)
# 2003-08-19
# Redistribution with or without modification as outlined by the GNU GPL.
# See the attached COPYING file for details.  If no such file was provided,
# a copy of the license can be obtained at http://www.gnu.org/licenses/gpl.html
#### Start editing here

bkfile="/var/backup/bkfiles.tar"
bklogs="/var/backup/bklogs.tar"
bkdirs="/etc /var/websites /home"
rmlogs="/bar/log/*.[0-9]*"
md5sumfile="/var/backup/md5sum-monthly"


gpgrecipient="KeyName"
bkhost="DestinationHost"
sshuser="username"

compressor="bzip2"
compressor_ext="bz2"

remote_bklogs="bklogs.`date +%b`.tar.$compressor_ext.gpg"
remote_bkfile="bkfiles.`date +%b`.tar.$compressor_ext.gpg"

#### Stop editing here

cd /

tar -Pcvf $bkfile $bkdirs
tar -Pcvf $bklogs /var/log

rm -f $rmlogs

$compressor $bkfile
$compressor $bklogs

bkfile=$bkfile.$compressor_ext
bklogs=$bklogs.$compressor_ext

rm $bkfile.gpg
rm $bklogs.gpg

gpg -r $gpgrecipient --encrypt $bkfile
gpg -r $gpgrecipient --encrypt $bklogs

bkfile=$bkfile.gpg 
bklogs=$bklogs.gpg

last_md5sum=`cat $md5sumfile`

current_md5sum=`md5sum $bkfile`

scp $bklogs $sshuser@$bkhost:~/$remote_bklogs

if [[ $last_md5sum != $current_md5sum ]]
then
	scp $bkfile $sshuser@$bkhost:~/$remote_bkfile
	remote_md5sum=`ssh $sshuser@$bkhost md5sum $remote_bkfile`
		echo "MD5SUM report" 
		echo "Local: $current_md5sum"
		echo "Remote: $remote_md5sum"
		exit 1
fi
echo $current_md5sum > $md5sumfile
